@@ -21,7 +21,7 @@ public:
 
 public Q_SLOTS:
 
-    void doGrab(Platform::ShutterMode theShutterMode, Platform::GrabMode theGrabMode, bool theIncludePointer, bool theIncludeDecorations) override final;
+    void doGrab(Platform::ShutterMode shutterMode, Platform::GrabMode grabMode, bool includePointer, bool includeDecorations) override final;
 };
 
 class VideoPlatformNull final : public VideoPlatform
@@ -35,7 +35,9 @@ public:
     void startRecording(const QString &path, RecordingMode recordingMode, const RecordingOption &option, bool includePointer) override;
     void finishRecording() override;
 
+    void setExtension(const QString &encoder) override;
     QString extension() const override;
+    QStringList suggestedExtensions() const override;
 
 private:
     QString m_path;
